@@ -4,6 +4,7 @@
 #' @param x data.frame with ID, toID, and area columns.
 #' @return numeric with total area.
 #' @importFrom dplyr select left_join
+#' @importFrom hydroloom accumulate_downstream
 #' @export
 #' @examples
 #' library(dplyr)
@@ -57,38 +58,3 @@ calculate_arbolate_sum <- function(x) {
   return(accumulate_downstream(x, "length"))
 
 }
-
-#' @importFrom dplyr select left_join ungroup distinct
-#' @importFrom rlang .data
-#' @noRd
-#'
-accumulate_downstream <- function(x, var) {
-
-  try(x <- st_drop_geometry(x), silent = TRUE)
-
-  cat_order <- select(x, "ID")
-
-  x[["toID"]] <- tidyr::replace_na(x[["toID"]], 0)
-
-  x <- get_sorted(x)
-
-  x[["toID_row"]] <- match(x[["toID"]], x[["ID"]])
-
-  var_out <- x[[var]]
-
-  if(any(is.na(x[[var]]))) {
-    warning("NA values found, accumulation math may fail.")
-  }
-
-  toid_row <- x[["toID_row"]]
-
-  for(cat in 1:length(var_out)) {
-    var_out[toid_row[cat]] <- var_out[toid_row[cat]] + var_out[cat]
-  }
-
-  x[[var]] <- var_out
-
-  x <- distinct(left_join(cat_order, x, by = "ID"))
-
-  return(x[[var]])
-}
